==> mouseCHRLOC_1.16.1.tar.gz: mouseCHRLOC/man/mouseCHRLOC6START.Rd <==
\name{mouseCHRLOC6START}
\alias{mouseCHRLOC6START}
\title{An annotation data file for transciption starting locations of genes
on chromosome 6}
\description{
  mouseCHRLOC6START maps Entrez Gene identifiers to the transciption starting
  locations of genes on chromosome number 6 corresponding to the
  Entrez Gene identifiers 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are Entrez Gene identifiers and values are the transciption starting location for
   genes. The starting positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors derived from the
   smallest starting value found for the Entrez Gene identifier. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\\url{http://gopher6/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Mus\_musculus/database/}. Built: No build info available.

   Package built: Fri Mar 16 09:57:00 2007
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(mouseCHRLOC6START)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}

==> mouseCHRLOC_2.1.6.tar.gz: mouseCHRLOC/man/mouseCHRLOC6START.Rd <==
\name{mouseCHRLOC6START}
\alias{mouseCHRLOC6START}
\title{An annotation data file for transciption starting locations of genes
on chromosome 6}
\description{
  mouseCHRLOC6START maps Entrez Gene identifiers to the transciption starting
  locations of genes on chromosome number 6 corresponding to the
  Entrez Gene identifiers 
}
\details{
   This is an environment object containing key and value pairs. Keys
   are Entrez Gene identifiers and values are the transciption starting location for
   genes. The starting positions for genes on both the sense and antisense
   strand are number of base pairs measured from the p (5' end of the
   sense strand) to q (3' end of the sense strand) arms. Values for the
   antisense strand have a leading "-" sign (e. g. -1234567).

   Values for keys are named vectors derived from the
   smallest starting value found for the Entrez Gene identifier. Names of chromosome
   location values can be "Confident" when the gene can be confidently
   placed on a chromosome and "Unconfident" otherwise (denoted by
   "\_random" in UCSC data).

   Mappings were derived from the following public data sources:

   Golden Path:\url{http://gopher6/compbio/annotationSourceData/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Mus_musculus/database/}. Built: No build info available.

   Package built: Thu Aug 30 09:55:54 2007
}
\references{
\url{http://www.genome.ucsc.edu/goldenPath/hg16/database/}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(mouseCHRLOC6START)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[1]
		# Get the values for a few keys
		if(length(xx) >= 3){
		    xx[1:3]
		}
	}
}
\keyword{datasets}
